@@ -1,11 +1,13 @@
-use v5.38;
-use feature 'class';
-no warnings 'experimental::class';
+use v5.28;
+use warnings;
+use Object::Pad 0.73;
 
-class Archive::SCS::DirIndex 0.03;
+class Archive::SCS::DirIndex 1.00;
 
 field $dirs  :param = [];
 field $files :param = [];
 
 method dirs () { $dirs->@* }
 method files () { $files->@* }
+
+1;
