@@ -1,10 +1,12 @@
-use v5.39.2;
-use feature 'class';
-no warnings 'experimental::class';
+use v5.32;
+use warnings;
+use Object::Pad 0.73;
 
-class Archive::SCS::HashFS2 0.03
+class Archive::SCS::HashFS2 1.00
   :isa( Archive::SCS::Mountable );
 
+use stable 0.031 'isa';
+
 use Archive::SCS::CityHash qw(
   cityhash64
   cityhash64_int
@@ -399,6 +401,8 @@ sub _compress_zlib ($data) {
   return $rfc1950header . $compressed;
 }
 
+1;
+
 
 =head1 NAME
 
