@@ -1,8 +1,8 @@
-use v5.38;
-use feature 'class';
-no warnings 'experimental::class';
+use v5.28;
+use warnings;
+use Object::Pad 0.73;
 
-class Archive::SCS::TObj 0.03;
+class Archive::SCS::TObj 1.00;
 
 field $meta  :param;
 field $data  :param;
@@ -12,3 +12,5 @@ method _meta () {$meta}
 method dds () {$data}
 
 method tobj () {}
+
+1;
